@@ -1,8 +1,8 @@
 from typing import Dict
 
 from blacksmith.domain.model.http import HTTPRequest, HTTPResponse
-from blacksmith.typing import ClientName, HttpMethod, Path
 from blacksmith.domain.typing import AsyncMiddleware
+from blacksmith.typing import ClientName, HttpMethod, Path
 
 
 class AsyncHTTPMiddleware:
@@ -24,7 +24,11 @@ class AsyncHTTPMiddleware:
 
 
 class AsyncHTTPAddHeadersMiddleware(AsyncHTTPMiddleware):
-    """Generic middleware that inject header."""
+    """
+    Generic middleware that inject HTTP headers.
+
+    :params: headers to inject in HTTP requests.
+    """
 
     headers: Dict[str, str]
 
